@@ -9,7 +9,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tclMacTest.c 1.9 97/09/09 16:36:37
+ * RCS: @(#) $Id: tclMacTest.c,v 1.4 1999/05/11 07:13:36 jingham Exp $
  */
 
 #define TCL_TEST
@@ -29,7 +29,6 @@
  */
 
 int			TclplatformtestInit _ANSI_ARGS_((Tcl_Interp *interp));
-int			Mactest_Init _ANSI_ARGS_((Tcl_Interp *interp));
 static int		DebuggerCmd _ANSI_ARGS_((ClientData dummy,
 			    Tcl_Interp *interp, int argc, char **argv));
 static int		WriteTextResource _ANSI_ARGS_((ClientData dummy,
@@ -39,7 +38,7 @@ static int		WriteTextResource _ANSI_ARGS_((ClientData dummy,
 /*
  *----------------------------------------------------------------------
  *
- * Mactest_Init --
+ * TclplatformtestInit --
  *
  *	Defines commands that test platform specific functionality for
  *	Unix platforms.
@@ -54,16 +53,9 @@ static int		WriteTextResource _ANSI_ARGS_((ClientData dummy,
  */
 
 int
-Mactest_Init (
+TclplatformtestInit(
     Tcl_Interp *interp)		/* Interpreter to add commands to. */
 {
-    if (Tcl_PkgRequire(interp, "Tcl", TCL_VERSION, 1) == NULL) {
-	return TCL_ERROR;
-    }
-    if (Tcl_PkgProvide(interp, "Tclptest", TCL_VERSION) != TCL_OK) {
-        return TCL_ERROR;
-    }
-
     /*
      * Add commands for platform specific tests on MacOS here.
      */
@@ -76,29 +68,6 @@ Mactest_Init (
     return TCL_OK;
 }
 
-/*
- *----------------------------------------------------------------------
- *
- * TclplatformtestInit --
- *
- *	Defines commands that test platform specific functionality for
- *	Mac platforms.
- *
- * Results:
- *	A standard Tcl result.
- *
- * Side effects:
- *	Defines new commands.
- *
- *----------------------------------------------------------------------
- */
-
-int
-TclplatformtestInit (
-    Tcl_Interp *interp)		/* Interpreter to add commands to. */
-{
-    return Mactest_Init(interp);
-}
 /*
  *----------------------------------------------------------------------
  *
@@ -219,11 +188,11 @@ WriteTextResource(
     strcpy((char *) resourceName, rsrcName);
     c2pstr((char *) resourceName);
     
-    dataHandle = NewHandle(strlen(data) + 1);
+    dataHandle = NewHandle(strlen(data));
     HLock(dataHandle);
     strcpy(*dataHandle, data);
     HUnlock(dataHandle);
-    
+     
     /*
      * Add the resource to the file and close it.
      */
@@ -242,32 +211,3 @@ WriteTextResource(
 	    (char *) NULL);
     return TCL_ERROR;
 }
-
-int
-TclMacChmod(
-    char *path, 
-    int mode)
-{
-    HParamBlockRec hpb;
-    OSErr err;
-    
-    c2pstr(path);
-    hpb.fileParam.ioNamePtr = (unsigned char *) path;
-    hpb.fileParam.ioVRefNum = 0;
-    hpb.fileParam.ioDirID = 0;
-    
-    if (mode & 0200) {
-        err = PBHRstFLockSync(&hpb);
-    } else {
-        err = PBHSetFLockSync(&hpb);
-    }
-    p2cstr((unsigned char *) path);
-    
-    if (err != noErr) {
-        errno = TclMacOSErrorToPosixError(err);
-        return -1;
-    }
-    
-    return 0;
-}
-
