@@ -10,7 +10,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * RCS: @(#) $Id: tclUnixChan.c,v 1.13 2000/01/26 03:38:00 hobbs Exp $
+ * RCS: @(#) $Id: tclUnixChan.c,v 1.17 2000/04/19 09:17:03 hobbs Exp $
  */
 
 #include	"tclInt.h"	/* Internal definitions for Tcl. */
@@ -502,7 +502,7 @@ FileSeekProc(instanceData, offset, mode, errorCodePtr)
     FileState *fsPtr = (FileState *) instanceData;
     int newLoc;
 
-    newLoc = lseek(fsPtr->fd, offset, mode);
+    newLoc = lseek(fsPtr->fd, (off_t) offset, mode);
 
     *errorCodePtr = (newLoc == -1) ? errno : 0;
     return newLoc;
@@ -1132,10 +1132,26 @@ TtyParseMode(interp, mode, speedPtr, parityPtr, dataPtr, stopPtr)
 	}
 	return TCL_ERROR;
     }
-    if (strchr("noems", parity) == NULL) {
+    /*
+     * Only allow setting mark/space parity on platforms that support it
+     * Make sure to allow for the case where strchr is a macro.
+     * [Bug: 5089]
+     */
+    if (
+#if defined(PAREXT) || defined(USE_TERMIO)
+	strchr("noems", parity) == NULL
+#else
+	strchr("noe", parity) == NULL
+#endif
+	) {
 	if (interp != NULL) {
 	    Tcl_AppendResult(interp, bad,
-		    " parity: should be n, o, e, m, or s", NULL);
+#if defined(PAREXT) || defined(USE_TERMIO)
+		    " parity: should be n, o, e, m, or s",
+#else
+		    " parity: should be n, o, or e",
+#endif
+		    NULL);
 	}
 	return TCL_ERROR;
     }
@@ -2041,7 +2057,27 @@ CreateSocket(interp, port, host, server, myaddr, myport, async)
                     asyncConnect = 1;
                     status = 0;
                 }
-            }
+	    } else {
+		/*
+		 * Here we are if the connect succeeds. In case of an
+		 * asynchronous connect we have to reset the channel to
+		 * blocking mode.  This appears to happen not very often,
+		 * but e.g. on a HP 9000/800 under HP-UX B.11.00 we enter
+		 * this stage. [Bug: 4388]
+		 */
+		if (async) {
+#ifndef USE_FIONBIO
+		    origState = fcntl(sock, F_GETFL);
+		    curState = origState & ~(O_NONBLOCK);
+		    status = fcntl(sock, F_SETFL, curState);
+#endif
+
+#ifdef  USE_FIONBIO
+		    curState = 0;
+		    status = ioctl(sock, FIONBIO, &curState);
+#endif
+		}
+	    }
         }
     }
 
